require 'git'
class GitoFigure
  attr_accessor :repo
  REPOS = '/tmp/gitolites'

  def initialize(ops={})
    @repo = ops[:repo]
  end

  def self.administer(server, overrides={})
    ops = {:git_user => 'gitolite', :repo => 'gitolite-admin', :server => server}.merge overrides
    upstream_url = ops[:git_user] + '@' + ops[:server] + ':' + ops[:repo]
    local_path = File.join(REPOS, ops[:server])
    git = GitoFigure.new

    git.repo = Dir.exists?(local_path) ? Git.open(local_path) : Git.clone(upstream_url, ops[:server], :path => REPOS)

    if block_given?
      git.repo.pull
      yield git
      git.repo.push
    else
      return git
    end
  end

  def authorize_keys(hsh)
    hsh.each do |name, key|
      filename = File.join('/', 'tmp', name.to_s + '.pub')
      File.open(filename, "w") {|f| f.write(key.to_s)}
      authorize_keyfile(filename)
    end
  end
  
  def authorize_keyfile(filename, msg=nil)
    msg = ["Added #{File.basename(filename)}", msg].join("\n")
    FileUtils.mv(filename, repo.dir.to_s + '/keydir')
    repo.add 'keydir'
    repo.commit(msg)
  end
end
